<?php
/*
Plugin Name: Backlink-Sharing.de Embed Plugin
Description: Ein Plugin, um Partnerlinks von Backlink-Sharing.de über einen Shortcode einzubinden.
Version: 1.1
Author: Varga-Tech
*/

if (!defined('ABSPATH')) {
    exit; // Direktzugriff verhindern
}

// Shortcode für die Einbettung der Partnerlinks
function backlink_embed_shortcode() {
    // API-Key aus den Einstellungen abrufen
    $api_key = get_option('backlink_embed_api_key');
    if (empty($api_key)) {
        return "<p style='color: red;'>API-Schlüssel ist nicht konfiguriert. Bitte im Admin-Bereich festlegen.</p>";
    }

    // Externe URL der embed.php-Datei mit API-Key
    $embed_url = 'https://www.backlink-sharing.de/embed.php?api_key=' . urlencode($api_key);

    ob_start();
    ?>
    <div id="backlink-embed-container"></div>
    <script type="text/javascript">
        (function() {
            var script = document.createElement("script");
            script.src = "<?php echo esc_url($embed_url); ?>";
            script.async = true;
            document.getElementById("backlink-embed-container").appendChild(script);
        })();
    </script>
    <?php
    return ob_get_clean();
}
add_shortcode('backlink_embed', 'backlink_embed_shortcode');

// Menüpunkt im Admin-Bereich hinzufügen
function backlink_embed_menu() {
    add_options_page(
        'Backlink-Sharing.de Einstellungen',
        'Backlink-Sharing Embed',
        'manage_options',
        'backlink-sharing',
        'backlink_embed_settings_page'
    );
}
add_action('admin_menu', 'backlink_embed_menu');

// Einstellungsseite für den API-Schlüssel
function backlink_embed_settings_page() {
    ?>
    <div class="wrap">
        <h1>Backlink-Sharing.de Einstellungen</h1>
        <form method="post" action="options.php">
            <?php
            settings_fields('backlink_embed_options');
            do_settings_sections('backlink-sharing');
            submit_button();
            ?>
        </form>
    </div>
    <?php
}

// API-Key-Einstellungen initialisieren
function backlink_embed_settings_init() {
    register_setting('backlink_embed_options', 'backlink_embed_api_key');

    add_settings_section(
        'backlink_embed_section',
        'API-Schlüssel Einstellungen',
        'backlink_embed_section_callback',
        'backlink-sharing'
    );

    add_settings_field(
        'backlink_embed_api_key',
        'API-Schlüssel',
        'backlink_embed_api_key_callback',
        'backlink-sharing',
        'backlink_embed_section'
    );
}
add_action('admin_init', 'backlink_embed_settings_init');

// Beschreibung für die Sektion
function backlink_embed_section_callback() {
    echo 'Geben Sie hier Ihren API-Schlüssel ein, um die Partnerlinks von Backlink-Sharing.de zu integrieren.';
}

// Eingabefeld für den API-Schlüssel
function backlink_embed_api_key_callback() {
    $api_key = get_option('backlink_embed_api_key');
    echo '<input type="text" id="backlink_embed_api_key" name="backlink_embed_api_key" value="' . esc_attr($api_key) . '" size="50" />';
}
